Learn R Programming

orbweaver (version 0.10.2)

get_leaves_under: Get the leaf nodes of a graph under some nodes

Description

Retrieves the nodes in a graph that have no children under a certain node or group of nodes

Usage

get_leaves_under(graph, nodes)

Value

A character vector of nodes

Arguments

graph

A graph object

nodes

A character vector of nodes to find leaves for